@@ -370,7 +370,7 @@ class ModelCheckpointCallback(Callback):
         Running minimum of the metric.
     """
 
-    def __init__(self, folder_path, dataloader_name, metric_name, verbose=False, save_best_only=False):
+    def __init__(self, folder_path, dataloader_name, metric_name, verbose=False):
         self.folder_path = pathlib.Path(folder_path)
         if self.folder_path.is_file():
             raise NotADirectoryError('The checkpointing path needs to be a folder.')
@@ -378,7 +378,6 @@ class ModelCheckpointCallback(Callback):
         self.dataloader_name = dataloader_name
         self.metric_name = metric_name
         self.verbose = verbose
-        self.save_best_only = save_best_only
 
         self.min = np.inf
         self.run = None  # will be injected with an instance of ``Run``.
@@ -522,14 +521,13 @@ class TensorBoardCallback(Callback):
     Currently supports:
         - images (evolution of predicted weights over time)
         - histograms (activations of input and outputs of all layers)
-        - hyperparamters
         - scalars (logged metrics)
 
     Parameters
     ----------
     log_dir : None or str or pathlib.Path
         Represent the folder where to checkpoints will be saved. If None then using
-        `cwd/runs/CURRENT_DATETIME_HOSTNAME`. Else the exact path.
+        the current working directory. Else the exact path.
 
     ts : datetime.datetime or None
         If ``datetime.datetime``, then only logging specific sample corresponding to provided timestamp.
@@ -606,7 +604,6 @@ class TensorBoardCallback(Callback):
     def on_epoch_end(self, metadata):
         """Log images, metrics and hyperparamters."""
         epoch = metadata.get('epoch')
-        n_epochs = metadata.get('n_epochs')
 
         # create weight image
         master_df = pd.concat(self.weights).sort_index()
@@ -623,9 +620,6 @@ class TensorBoardCallback(Callback):
             for metric_name, metric_value in metrics.items():
                 self.writer.add_scalar(metric_name, metric_value, global_step=epoch)
 
-            if epoch == n_epochs - 1:
-                self.writer.add_hparams(self.run.hparams, metrics)
-
         except KeyError:
             pass
 
