@@ -332,7 +332,7 @@ class Resample(nn.Module):
         portfolios = []  # n_portfolios elements of (n_samples, n_assets)
 
         for _ in range(self.n_portfolios):
-            draws = dist.sample((n_draws,))  # (n_draws, n_samples, n_assets)
+            draws = dist.rsample((n_draws,))  # (n_draws, n_samples, n_assets)
             rets_ = draws.mean(dim=0) if rets is not None else None  # (n_samples, n_assets)
             covmat_ = CovarianceMatrix(sqrt=self.uses_sqrt)(draws.permute(1, 0, 2))  # (n_samples, n_assets, ...)
 
@@ -545,3 +545,64 @@ class WeightNorm(torch.nn.Module):
         normalized = clamped / clamped.sum()
 
         return torch.stack(n_samples * [normalized], dim=0)
+
+
+class NumericalRiskBudgeting(nn.Module):
+    """Convex optimization layer stylized into portfolio optimization problem.
+
+    Parameters
+    ----------
+    n_assets : int
+        Number of assets.
+
+    Attributes
+    ----------
+    cvxpylayer : CvxpyLayer
+        Custom layer used by a third party package called cvxpylayers.
+
+    References
+    ----------
+    [1] https://github.com/cvxgrp/cvxpylayers
+    [2] https://papers.ssrn.com/sol3/papers.cfm?abstract_id=2297383
+    [3] https://mpra.ub.uni-muenchen.de/37749/2/MPRA_paper_37749.pdf
+    """
+
+    def __init__(self, n_assets, max_weight=1):
+        """Construct."""
+        super().__init__()
+        covmat_sqrt = cp.Parameter((n_assets, n_assets))
+        b = cp.Parameter(n_assets, nonneg=True)
+
+        w = cp.Variable(n_assets)
+
+        term_1 = 0.5 * cp.sum_squares(covmat_sqrt @ w)
+        term_2 = b @ cp.log(w)
+
+        objective = cp.Minimize(term_1 - term_2)  # refer [2]
+        constraint = [cp.sum(w) == 1, w >= 0, w <= max_weight]  # refer [2]
+
+        prob = cp.Problem(objective, constraint)
+
+        assert prob.is_dpp()
+
+        self.cvxpylayer = CvxpyLayer(prob, parameters=[covmat_sqrt, b], variables=[w])
+
+    def forward(self, covmat_sqrt, b):
+        """Perform forward pass.
+
+        Parameters
+        ----------
+        covmat : torch.Tensor
+            Of shape (n_samples, n_assets, n_assets) representing the covariance matrix.
+
+        b : torch.Tensor
+            Of shape (n_samples, n_assets) representing the budget,
+            risk contribution from each component (asset) is equal to the budget, refer [3]
+
+        Returns
+        -------
+        weights : torch.Tensor
+            Of shape (n_samples, n_assets) representing the optimal weights as determined by the convex optimizer.
+
+        """
+        return self.cvxpylayer(covmat_sqrt, b)[0]
